==> haskell-unliftio-0.1.0.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio
version: 0.1.0.0
id: unliftio-0.1.0.0-AwFFXYSjGKDWkCj4rvO8X
key: unliftio-0.1.0.0-AwFFXYSjGKDWkCj4rvO8X
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/monad-unlift/tree/master/unliftio#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)
description:
    Please see the README.md file for details
category: Control
author: Michael Snoyman, Francesco Mazzoli
exposed: True
indefinite: False
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Exception
    UnliftIO.IO UnliftIO.IORef UnliftIO.Instances UnliftIO.MVar
    UnliftIO.Resource UnliftIO.Temporary UnliftIO.Timeout
hidden-modules: Paths_unliftio
abi: 07f4e7a3050b6594cb86385f01d1507d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/unliftio-0.1.0.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/unliftio-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/unliftio-0.1.0.0
hs-libraries: HSunliftio-0.1.0.0-AwFFXYSjGKDWkCj4rvO8X
depends:
    base-4.10.0.0 async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2
    monad-logger-0.3.25-5LXzWlorzBH2byyO84WbrV
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9 transformers-0.5.2.0
    unliftio-core-0.1.0.0-7dxXCheCbWw5AYq7pnmhLl unix-2.7.2.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             monad-logger-0.3.25-5LXzWlorzBH2byyO84WbrV=7ac3c56d74cd1c3b7f1128e63f80dca2
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unliftio-core-0.1.0.0-7dxXCheCbWw5AYq7pnmhLl=5342fc877b9186e2d07ec8389a5daa43
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
haddock-interfaces: /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html: /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-0.1.0.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio
version: 0.1.0.0
id: unliftio-0.1.0.0-2B6hUEHiCoNDdLcBD9ZiH5
key: unliftio-0.1.0.0-2B6hUEHiCoNDdLcBD9ZiH5
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/monad-unlift/tree/master/unliftio#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)
description:
    Please see the README.md file for details
category: Control
author: Michael Snoyman, Francesco Mazzoli
exposed: True
indefinite: False
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Exception
    UnliftIO.IO UnliftIO.IORef UnliftIO.Instances UnliftIO.MVar
    UnliftIO.Resource UnliftIO.Temporary UnliftIO.Timeout
hidden-modules: Paths_unliftio
abi: c76e02fce72cfc668c4a90002450386d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/unliftio-0.1.0.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/unliftio-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/unliftio-0.1.0.0
hs-libraries: HSunliftio-0.1.0.0-2B6hUEHiCoNDdLcBD9ZiH5
depends:
    base-4.10.0.0 async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2
    monad-logger-0.3.25-KuF0WvNKa4vJG5V6HuPAhN
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9 transformers-0.5.2.0
    unliftio-core-0.1.0.0-7dxXCheCbWw5AYq7pnmhLl unix-2.7.2.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             monad-logger-0.3.25-KuF0WvNKa4vJG5V6HuPAhN=7c40a0a2332f1fdfc6c61a4a6fd254af
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unliftio-core-0.1.0.0-7dxXCheCbWw5AYq7pnmhLl=5342fc877b9186e2d07ec8389a5daa43
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
haddock-interfaces: /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html: /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
